#!/bin/bash

# This script waits for netdata to be up and running by waiting for
# the xenstat plugin to be loaded and executed, then exits or timeouts
# after 20 seconds. It exits immediately if netdata is not running.
#
# This script is intended to be used by systemd as ExecStop program to
# delay the termination of netdata while it is starting (i.e. calling
# 'systemctl start' and 'systemctl stop' immediately after).

[ -z "${MAINPID}" ] && exit 0

XENSTAT_PLUGIN=xenstat.plugin

COUNT=0
while [ ${COUNT} -lt 20 ] &&
      [ -d /proc/${MAINPID} ] &&
      ! ps --ppid ${MAINPID} | grep -q ${XENSTAT_PLUGIN}; do
    sleep 1
    ((COUNT++))
done

# If we've been waiting on xenstat.plugin, just wait a bit more
# to make sure we're really started
[ ${COUNT} -ne 0 ] && sleep 3

exit 0
